package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.SysLogin;
import com.example.civilizedcity.service.SysLoginService;

 /**
 * 系统账户表;(sys_login)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-12
 */
@Api(tags = "系统账户表对象功能接口")
@RestController
@RequestMapping("/")
public class SysLoginController extends BaseController {
    
    @Autowired
    private SysLoginService sysLoginService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param loginId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysLogin/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(sysLoginService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/sysLogin")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<SysLogin> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<SysLogin> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<SysLogin> result = sysLoginService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param sysLogin 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/sysLogin")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody SysLogin sysLogin) throws Exception {
        sysLoginService.save(sysLogin);
        return ResponseBean.success(sysLogin);
    }
    
    /** 
     * 更新数据
     *
     * @param sysLogin 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/sysLogin/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody SysLogin sysLogin,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        sysLoginService.updateById(sysLogin);
        return ResponseBean.success(sysLogin);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param loginId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysLogin/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        sysLoginService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}